@@ -28,7 +28,7 @@ function scrollbarWidth() {
 function reloadGraphs(max_image_width) {
     $('a.replace-with-image').each(
         function (index) {
-            var url, url_click, timestamp, width, height, amp_or_questionmark, 
+            var url, url_click, timestamp, width, height, amp_or_questionmark,
             html_img, image, $main_tag, html_src, html_url, errormsg;
             $main_tag = $(this);
             width = $(this).parent('.img-use-my-size').innerWidth();
@@ -127,13 +127,17 @@ function calculateHiddenStuffHeight() {
 
 function stretchOneSidebarBox() {
     /* Stretch out one sidebarbox so that the sidebar is completely filled. */
-    var stillAvailable, includeMargin;
-    $("#sidebar .sidebarbox-stretched").height('0');
+    var stillAvailable, includeMargin, minHeight, autoHeight, newHeight;
+    minHeight = 100; // not smaller than this
+    $("#sidebar .sidebarbox-stretched").height('auto');
+    autoHeight = $("#sidebar .sidebarbox-stretched").height();
     stillAvailable = $("#sidebar").innerHeight();
     $("#sidebar > *").each(function () {
         stillAvailable -= $(this).outerHeight(includeMargin = true);
     });
-    $("#sidebar .sidebarbox-stretched").height(stillAvailable);
+    newHeight = autoHeight + stillAvailable;
+    newHeight = newHeight < minHeight ? minHeight : newHeight;
+    $("#sidebar .sidebarbox-stretched").height(newHeight);
 }
 
 
@@ -193,6 +197,9 @@ function fillScreen() {
     $('#graph-popup-content').css(
         'max-height',
         mainContentHeight - 30);
+    $('.popup-content').css(
+        'max-height',
+        mainContentHeight - 30);
 }
 
 
@@ -346,7 +353,7 @@ function setUpAccordion() {
         {tabs: "h2, h3",
          effect: "slide"});
     /* Set up a global 'accordion' variable to later steer the animation. */
-    accordion = $("#accordion").tabs();
+    accordion = $("#accordion").data("tabs");
     $(".accordion-load-next a").live('click', function (event) {
         var pane, nextPaneId, url, newTitle;
         event.preventDefault();
