@@ -14,6 +14,9 @@ urlpatterns = patterns(
     url(r'^accounts/logout/$',
         'lizard_ui.views.simple_logout',
         name='lizard_ui.logout'),
+    url(r'^screen/(?P<application_screen_slug>.*)/$',
+        'lizard_ui.views.application_screen',
+        name='lizard_ui.application_screen'),
     )
 
 
@@ -55,4 +58,15 @@ if settings.DEBUG:  # Pragma: nocover
          {'template': 'lizard_ui/example_accordion3.html'}),
         (r'^examples/icons/$', 'direct_to_template',
          {'template': 'lizard_ui/example_icons.html'}),
+        (r'^examples/portaltabs/$', 'direct_to_template',
+         {'template': 'lizard_ui/example-portaltabs.html'}),
+        (r'^examples/appscreens/$', 'direct_to_template',
+         {'template': 'lizard_ui/example-appscreens.html'}),
+        )
+    urlpatterns += patterns(
+        '',
+        url(r'^examples/breadcrumbs/$',
+            'lizard_ui.views.example_breadcrumbs',
+            {'template': 'lizard_ui/example-breadcrumbs.html'},
+            name='lizard_ui.example_breadcrumbs'),
         )
